@@ -607,16 +607,22 @@ struct ManhattenCollapse {
 	Eigen::DenseIndex smr, smc;
 	double bestFit;
 	Eigen::DenseIndex bestR, bestC;
+	double minExpected;
 	
 	ManhattenCollapse(int rows, int cols, double *oMem, double *eMem)
-		: obs(oMem, rows, cols), expected(eMem, rows, cols) {}
+		: obs(oMem, rows, cols), expected(eMem, rows, cols),
+		  minExpected(KANG_CHEN_MIN_EXPECTED) {};
+	void setMinExpected(double th) { minExpected = th; };
 	void probe(Eigen::DenseIndex br, Eigen::DenseIndex bc);
+	double findMinCoeff(Eigen::DenseIndex *br, Eigen::DenseIndex *bc);
 	int run();
 };
 
 void ManhattenCollapse::probe(Eigen::DenseIndex br, Eigen::DenseIndex bc)
 {
-	if (br < 0 || bc < 0 || br >= expected.rows() || bc >= expected.cols()) return;
+	bool outside = (br < 0 || bc < 0 ||
+			br >= expected.rows() || bc >= expected.cols());
+	if (outside) return;
 	if (expected(br, bc) < bestFit) {
 		bestFit = expected(br, bc);
 		bestR = br;
@@ -624,45 +630,57 @@ void ManhattenCollapse::probe(Eigen::DenseIndex br, Eigen::DenseIndex bc)
 	}
 }
 
+double ManhattenCollapse::findMinCoeff(Eigen::DenseIndex *br, Eigen::DenseIndex *bc)
+{
+	// Eigen's minCoeff is not defined when some cells contain NaN
+	double mc = 1e100;
+	for (int cx=0; cx < expected.cols(); ++cx) {
+		for (int rx=0; rx < expected.rows(); ++rx) {
+			if (expected(rx,cx) < mc) {
+				mc = expected(rx,cx);
+				*br = rx;
+				*bc = cx;
+			}
+		}
+	}
+	return mc;
+}
+
 int ManhattenCollapse::run()
 {
-	const double worstFit = 1e100;
 	const int maxDist = obs.rows() + obs.cols();
 	int collapsed = 0;
 
-	while (expected.minCoeff(&smr, &smc) < KANG_CHEN_MIN_EXPECTED) {
-		bool done = false;
-		for (int dist=1; dist < maxDist && !done; ++dist) {
-			for (int updown=0; updown <= dist && !done; ++updown) {
+	while (findMinCoeff(&smr, &smc) < minExpected) {
+		bestFit = 1e100;
+		for (int dist=1; dist < maxDist; ++dist) {
+			for (int updown=0; updown <= dist; ++updown) {
 				int leftright = dist - updown;
-				bestFit = worstFit;
 				probe(smr + updown, smc + leftright);
 				probe(smr + updown, smc - leftright);
 				probe(smr - updown, smc + leftright);
 				probe(smr - updown, smc - leftright);
-				if (bestFit < worstFit) {
-					expected(bestR, bestC) += expected(smr, smc);
-					obs(bestR, bestC) += obs(smr, smc);
-					expected(smr, smc) = NA_REAL;
-					obs(smr, smc) = NA_REAL;
-					++collapsed;
-					done = true;
-				}
 			}
+			if (bestFit < minExpected) break;
 		}
-		if (!done) {
-			pda(expected.data(), expected.rows(), expected.cols());
-			Rf_error("Collapse algorithm failed");
-		}
+
+		expected(bestR, bestC) += expected(smr, smc);
+		obs(bestR, bestC) += obs(smr, smc);
+		expected(smr, smc) = NA_REAL;
+		obs(smr, smc) = NA_REAL;
+		++collapsed;
 	}
 
 	return collapsed;
 }
 
-SEXP collapse_wrapper(SEXP r_observed_orig, SEXP r_expected_orig)
+SEXP collapse_wrapper(SEXP r_observed_orig, SEXP r_expected_orig, SEXP r_min)
 {
 	ProtectAutoBalanceDoodad mpi;
 
+	if (!Rf_isMatrix(r_observed_orig)) Rf_error("observed must be a matrix");
+	if (!Rf_isMatrix(r_expected_orig)) Rf_error("expected must be a matrix");
+
   int rows, cols;
   getMatrixDims(r_expected_orig, &rows, &cols);
 
@@ -682,6 +700,7 @@ SEXP collapse_wrapper(SEXP r_observed_orig, SEXP r_expected_orig)
   double *expected = REAL(r_expected);
 
   ManhattenCollapse mcollapse(rows, cols, observed, expected);
+  if (Rf_length(r_min)) mcollapse.setMinExpected(Rf_asReal(r_min));
   int collapsed = mcollapse.run();
 
   SEXP dimnames;
